Puzzle Sets wrapping xword-dl for GNOME Crosswords

It should come with the flathub version of Crosswords and normally
shouldn't need to be built from scratch.

Here are some hints if you need to do so.

# Building (part 1): Source

First, install xword-dl. It's available in pip and in fedora

```shell
# Generic linux
$ pip install xword-dl

# Fedora
$ dnf install python3-xword-dl
```

Then, it should be buildable with meson.

```shell
$ meson setup _build
$ ninja -C _build
```

Running crosswords with `PUZZLE_SET_PATH=/path/to/_build/puzzle-sets/`
will load them into the game.

# Building (part 2): flatpak extension

Alternatively, you can build the flatpak extension manually.

```shell
flatpak-builder  --force-clean _flatpak/ org.gnome.Crosswords.PuzzleSets.xword-dl.json  --user --install
```

Then run the crosswords flatpak normally.

# Hints on updating to a new version xword-dl

This extension surprisingly finicky to update to a new version for
flatpak.

First, see if requirements.txt has changed, or needs updating from the
upstream repo. Copy the changes into our version.

Next, we explicitly need to add a newer version of six to the build,
so we have to remove it from the list of system_packages in
flatpak-pip-generator. If you update that file, make sure you change
it.

Once all that is done, run:
```shell
~/Projects/flatpak-builder-tools/pip/flatpak-pip-generator  --requirements-file=requirements.txt -o python3-requirements
```
to generate the new `python3-requirements.json` file.

Unfortunately, the requirements.txt file always brings surprises as it
changes, and flatpak-pip-generator isn'at able to keep up with it. As
a result, `python3-requirements.json` needs to be manually adjusted
everytime. In particular:
* both lxml and datetime need `--ignore-installed` set on the pip3
install command line.

Finally, make sure you update the wrapper script (`xword-dl`) so that
it has PYTHONPATH updated to include the new version of xword-dl. This
is possibly automatable, but it doesn't feel worth it for just this
one page.
